<?php 
/*
Plugin Name: CMS Navigation
Plugin URI: http://design.icanlocalize.com/wordpress-cms-plugins/cms-navigation-plugin/
Description: Adds CMS navigation functions to WP posts and pages
Author: ICanLocalize
Author URI: http://www.icanlocalize.com
Version: 0.1
*/

/*
    This file is part of CMS Navigation.

    CMS Navigation is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    CMS Navigation is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with CMS Navigation.  If not, see <http://www.gnu.org/licenses/>.
*/

define('CMS_NAVIGATION_VERSION', 0.1);

if(is_admin()) return;

function cms_navigation_breadcrumb(){
    ?><a href="<?php bloginfo('home') ?>"><?php echo __('Home') ?></a> &raquo; <?php 
    if(is_page()){
        global $post;
        if(is_array($post->ancestors)){            
            $ancestors = array_reverse($post->ancestors);
            foreach($ancestors as $anc){
                ?>
                <a href="<?php echo get_permalink($anc); ?>"><?php echo get_the_title($anc) ?></a> &raquo; 
                <?php
            }
            echo $post->post_title;
        }        
    }elseif(is_single()){
        $cat = get_the_category($id);
        $cat = $cat[0]->cat_ID;                
        echo(get_category_parents($cat, TRUE, ' &raquo; ')); 
        the_title();            
    }elseif (is_category()) {
        $cat = get_term(intval( get_query_var('cat')), 'category', OBJECT, 'display');
        if($cat->category_parent){
            echo get_category_parents($cat->category_parent, TRUE, ' &raquo; ');                 
        }
        single_cat_title();
    }elseif(is_tag()){
        echo __('Articles tagged ') ,'&#8216;'; 
        single_tag_title();
        echo '&#8217;';    
    }elseif (is_month()){
        echo the_time('F, Y');
    }elseif (is_search()){
        echo __('Search for: '), strip_tags(get_query_var('s'));
    /*    
    }elseif (is_404()){
        echo __('Not found');
    */
    }        
}

function cms_navigation_menu_nav($order='menu_order',$show_cat_menu=false, $cat_menu_title='News'){
    global $wpdb, $post;
    if(!$post->ancestors){
        $post->ancestors = array();
    }       
    $pages = $wpdb->get_col("SELECT ID FROM {$wpdb->posts} WHERE post_type='page' AND post_status='publish' AND post_parent=0 ORDER BY {$order}");   
    if($pages){   
        ?><ul id="cms-nav-top-menu"><?php
        foreach($pages as $p){
            $subpages = $wpdb->get_col("SELECT ID FROM {$wpdb->posts} WHERE post_parent={$p} AND post_status='publish' ORDER BY {$order}");
            if($p==$post->ID || in_array($p,$post->ancestors)){
                $sel = true;
            }else{
                $sel = false;
            }                        
            ?><li><a href="<?php echo $p==$post->ID?'#':get_permalink($p); ?>" class="<?php if($sel):?>selected <?php endif?><?php if($subpages):?>trigger<?php endif?>"><?php echo get_the_title($p) ?></a>
                <?php if($subpages):?>
                    <ul>
                        <?php foreach($subpages as $sp): ?>
                        <li>
                            <?php if($sp==$post->ID):?><span class="selected"><?php endif?>
                            <?php if($sp!=$post->ID):?><a href="<?php echo get_permalink($sp); ?>" <?php if(in_array($sp,$post->ancestors)): ?>class="selected"<?php endif;?>><?php endif?><?php echo get_the_title($sp) ?><?php if($sp!=$post->ID):?></a><?php endif?>
                            <?php if($sp==$post->ID):?></span><?php endif?>
                        </li>
                        <?php endforeach; ?>
                    </ul>
                <?php endif; ?>                    
            </li>
            <?php
        }
        //add categories
        if($show_cat_menu){
            wp_list_categories('title_li=<a class="trigger" href="'.get_option('home').'">'.$cat_menu_title.'</a>'.
                '&current_category='.intval(get_query_var('cat')).'&depth=1');
        }
        ?></ul><br class="cms-nav-clearit" /><?php
    }
}

function cms_navigation_page_navigation($order='menu_order'){
    if(!is_page()) return;
    global $post, $wpdb;  
    
    // is home?
    $is_home = get_post_meta($post->ID,'bp_minihome',true);
    
    if($is_home || !$post->ancestors){
        $pid = $post->ID;
    }else{
        //get top level page parent or home
        $parent = $post->ancestors[0];    
        
        do{
            $uppost = $wpdb->get_row("
                SELECT p1.ID, p1.post_parent, p2.meta_value IS NOT NULL AS minihome 
                FROM {$wpdb->posts} p1
                    LEFT JOIN {$wpdb->postmeta} p2 ON p1.ID=p2.post_id AND (meta_key='bp_minihome' OR meta_key IS NULL)
                    WHERE post_type='page' AND p1.ID={$parent}
            ");
            $pid = $uppost->ID;
            $parent = $uppost->post_parent;
            $minihome = $uppost->minihome;        
        }while($parent!=0 && !$minihome);
    } 
              
    ?><h4><?php if($pid!=$post->ID):?><a href="<?php echo get_permalink($pid); ?>"><?php endif;?><?php echo get_the_title($pid) ?><?php if($pid!=$post->ID):?></a><?php endif;?></h4><?php              
    
    $sub = $wpdb->get_results("
            SELECT p1.ID, meta_value AS section FROM {$wpdb->posts} p1 
            LEFT JOIN {$wpdb->postmeta} p2 ON p1.ID=p2.post_id AND (meta_key='bp_section' OR meta_key IS NULL)
            WHERE post_parent={$pid} AND post_status='publish' ORDER BY {$order}"); 
    if(empty($sub))  return;                   
    foreach($sub as $s){
        if(!$s->section){
            $s->section = '0__NO_SECTION__';
        }
        $sections[$s->section][] = $s->ID;    
    }
    ksort($sections);    
    foreach($sections as $sec_name=>$sec){
        ?>
        <ul class="cms-nav-left-menu">
            <li class="cms-nav-sub-section"><?php echo $sec_name=='0__NO_SECTION__'?'':$sec_name; ?></li>
            <?php foreach($sec as $s):?>
            <li>
                <?php if($post->ID==$s):?><span class="selected"><?php endif;?>
                <?php if($post->ID!=$s):?><a href="<?php echo get_permalink($s); ?>"><?php endif?><?php echo get_the_title($s) ?><?php if($post->ID!=$s):?></a><?php endif?>
                <?php if($post->ID==$s):?></span><?php endif;?>
                <?php cms_navigation_child_pages_recursive($s) ?>
            </li>
            <?php endforeach;?>
        </ul>
        <?php
    }
}

function cms_navigation_child_pages_recursive($pid){
    global $wpdb, $post;    
    $subpages = $wpdb->get_results("
        SELECT p1.ID, p2.meta_value IS NOT NULL AS minihome FROM {$wpdb->posts} p1 
        LEFT JOIN {$wpdb->postmeta} p2 ON p1.ID=p2.post_id AND (meta_key='bp_minihome' OR meta_key IS NULL)
        WHERE post_parent={$pid} AND post_type='page' AND post_status='publish'");
    ?>
    <?php if($subpages):?>
    <ul>
        <?php foreach($subpages as $s): ?>
        <li> 
            <?php if($post->ID==$s->ID):?><span class="selected"><?php endif;?>
            <?php if($post->ID!=$s->ID):?><a href="<?php echo get_permalink($s->ID)?>"><?php endif;?><?php echo get_the_title($s->ID) ?><?php if($post->ID!=$s->ID):?></a><?php endif;?>
            <?php if($post->ID==$s->ID):?></span><?php endif;?>
            <?php if(!$s->minihome) cms_navigation_child_pages_recursive($s->ID) ?>
        </li>
        <?php endforeach; ?>
    </ul>
    <?php endif; ?>
    <?php
}

//add_action('wp_head', cms_navigation_css); - THIS WOULD ADD THE STYLEHSEET *AFTER* THE THEME STYLESHEET
function cms_navigation_css($show=true){
    //make it MU and WP compatible
    $plugins_folder = basename(dirname(dirname(__FILE__)));
    $link_tag = '<link rel="stylesheet" href="'. get_option('home') . '/wp-content/' . $plugins_folder . '/CMS-Navigation/css/cms-navigation.css?ver=' . 
        CMS_NAVIGATION_VERSION .'" type="text/css" media="all" />';
    if(!$show){
        return $link_tag;
    }else{
        echo $link_tag;
    }
}

// THIS WOULD ADD THE STYLEHSEET *BEFORE* THE THEME STYLESHEET
add_action('init','cms_nav_ob_start');
function cms_nav_ob_start(){
    ob_start('cms_nav_prepend_css');
}
add_action('wp_head','cms_nav_ob_end');
function cms_nav_ob_end(){
    ob_end_flush();
}
function cms_nav_prepend_css($buf){
    return preg_replace('#</title>#i','</title>' . PHP_EOL . PHP_EOL . cms_navigation_css(false), $buf);
}